@@ -6,7 +6,33 @@ mythfs.pl - Mount Fuse filesystem to display TV recordings managed by a MythTV b
 
 =head1 SYNOPSIS
 
- % mythfs.pl mythbackend.mydomain.org /tmp/mythtv
+ % mythfs.pl [options] <Hostname of Backend> <mount point>
+
+Options:
+
+  --pattern=<pattern>          filename pattern default ("%T/%S")
+  --trim=<char>                 trim redundant occurrences of this character (no default)
+
+  --mountpt=<path>              mountpoint/directory for locally stored recordings (no default)
+  --Port=<port>                 HTTP request port on backend (6544)
+  --cachetime=<time>            cache time for recording names (10 minutes)
+
+  --unmount                     unmount the indicated directory
+  --foreground                  remain in foreground (false)
+  --nothreads                   disable threads (false)
+  --debug=<1,2>                 enable debugging. Pass -d 2 to trace Fuse operations (verbose!!)
+
+  --option=allow_other          allow other accounts to access filesystem (false)
+  --option=default_permissions  enable permission checking by kernel (false)
+  --option=fsname=name          set filesystem name (none)
+  --option=use_ino              let filesystem set inode numbers (false)
+  --option=nonempty             allow mounts over non-empty file/dir (false)
+
+  --help                        this text
+  --man                         full manual page
+
+Options can be abbreviated to single letters. For example you can
+abbreviate "--pattern=<pattern>" to "-p <pattern>".
 
 =head1 DESCRIPTION
 
@@ -15,22 +41,6 @@ recordings made by a MythTV (www.mythtv.org) backend. You must provide
 the name or IP address of the backend host, and the path to an empty
 directory to mount the virtual filesystem on.
 
-Options:
-   --unmount                     unmount the indicated directory
-   --cachetime=<time>            cache time for recording names (10 minutes)
-   --option=allow_other          allow other accounts to access filesystem (false)
-   --option=default_permissions  enable permission checking by kernel (false)
-   --option=fsname=name          set filesystem name (none)
-   --option=use_ino              let filesystem set inode numbers (false)
-   --option=nonempty             allow mounts over non-empty file/dir (false)
-   --pattern=<patterns>          filename pattern default ("%T/%S")
-   --mountpt=<path>              mountpoint/directory for locally stored recordings (no default)
-   --trim=<char>                 trim redundant occurrences of this character (no default)
-   --Port=<port>                 HTTP request port on backend (6544)
-   --foreground                  remain in foreground (false)
-   --debug=<1,2>                 enable debugging. Pass -d 2 to trace Fuse operations (verbose!!)
-   --nothreads                   disable threads (false)
-
 Filename patterns consist of regular characters and substitution
 patterns beginning with a %. Slashes (\/) will delimit directories and
 subdirectories. Empty directory names will be collapsed. The default
@@ -47,7 +57,6 @@ presented as symbolic links.
 Command line switches can abbreviated to single letters, so you can
 use "-p %T/%S" instead of "--pattern=%T/%S".
 
-
 If you request unmounting (using --unmount or -u), the first
 non-option argument is interpreted as the mountpoint, not the backend
 hostname.
@@ -160,6 +169,14 @@ counting subdirectories) contained within it. The modification time of
 directories is the start time of the most recent recording contained
 within it.
 
+Two automatically-created files are always present at the top level of
+the directory. "STATUS" contains a human-readable description of what
+happened the last time the script attempted to refresh the list of
+recordings from the backend. It is useful in diagnosing connection
+problems. ".fuse-mythfs" contains version and copyright information
+for this script, and can be used to detect if the Myth filesystem is
+mounted.
+
 =head2 Customizing the Directory Listing
 
 You may customize the directory listing by providing a pattern for
@@ -181,6 +198,8 @@ Commonly-used substitution patterns are:
     %T   = Title (show name)
     %S   = Subtitle (episode name)
     %C   = Category
+    %TC  = If part of a series, then Title, else Category
+    %ST  = If part of a series, then SubTitle, else Title
     %cn  = Channel: channel number
     %cN  = Channel: channel name
     %y   = Recording start time:  year, 2 digits
@@ -271,74 +290,38 @@ License 2.0. See http://www.perlfoundation.org/artistic_license_2_0.
 use strict;
 use warnings;
 use Net::MythTV::Fuse;
-use Getopt::Long qw(:config no_ignore_case);
 use File::Spec;
-use Fuse;
 use Config;
 use POSIX 'setsid';
 
+use Getopt::Long qw(:config no_ignore_case bundling_override);
+use Pod::Usage;
+
 my (@FuseOptions,$CacheTime,$Debug,$NoDaemon,$Pattern,
     $LocalMount,$NoThreads,$Delimiter,
     $HTTPPort,$UnMount,
+    $Help,$Man,
     $XMLDummyDataPath, # for debugging
     );
-my $Usage = <<END;
-Usage: $0 <Myth backend Host> <mountpoint>
 
-Fuse filesystem to mount recordings from Myth backend running on Host
-at the directory indicated by mountpoint: e.g. "mythfs.pl myhost
-/tmp/mythfs".
+GetOptions(
+    'help|h|?'     => \$Help,
+    'man|m'        => \$Man,
+    'option|o:s'   => \@FuseOptions,
+    'cachetime|c=f'=> \$CacheTime,
+    'foreground|f' => \$NoDaemon,
+    'pattern|p=s'  => \$Pattern,
+    'debug|d:i'    => \$Debug,
+    'trim|t=s'     => \$Delimiter,
+    'mountpt|m=s'  => \$LocalMount,
+    'Port|P=i'     => \$HTTPPort,
+    'nothreads|n'  => \$NoThreads,
+    'unmount|u'    => \$UnMount,
+    'XMLDummy|X=s' => \$XMLDummyDataPath,  # for debugging
+ ) or pod2usage(-verbose=>2);
 
-Options:
-   --unmount                     unmount a previously-mounted filesystem
-   --cachetime=<time>            cache time for recording names (10 minutes)
-   --option=allow_other          allow other accounts to access filesystem (false)
-   --option=default_permissions  enable permission checking by kernel (false)
-   --option=fsname=name          set filesystem name (none)
-   --option=use_ino              let filesystem set inode numbers (false)
-   --option=nonempty             allow mounts over non-empty file/dir (false)
-   --pattern=<patterns>          filename pattern default ("%T/%S")
-   --mountpt=<path>              mountpoint/directory for locally stored recordings (no default)
-   --trim=<char>                 trim redundant occurrences of this character (no default)
-   --Port=<port>                 HTTP request port on backend (6544)
-   --foreground                  remain in foreground (false)
-   --debug=<1,2>                 enable debugging. Pass -d 2 to trace Fuse operations (verbose!!)
-   --nothreads                   disable threads (false)
-
-Filename patterns consist of regular characters and substitution
-patterns beginning with a %. Slashes (\/) will delimit directories and
-subdirectories. Empty directory names will be collapsed. The default
-is "%T/%S", the recording title followed by the subtitle.  Run this
-command with "-p help" to get a list of all the substitution patterns
-recognized.
-
-By default, files will be streamed as needed from the myth
-backend. However, if the recording files are accessible directly from
-the filesystem (e.g. via an NFS mount), you can provide the path to
-this directory using the --mountpt option. The filenames will then be
-presented as symbolic links.
-
-Command line switches can abbreviated to single letters, so you can
-use "-p %T/%S" instead of "--pattern=%T/%S".
-
-If you request unmounting (using --unmount or -u), the first
-non-option argument is interpreted as the mountpoint, not the backend
-hostname.
-
-END
-    ;
-GetOptions('option:s'   => \@FuseOptions,
-	   'cachetime=i'=> \$CacheTime,
-	   'foreground' => \$NoDaemon,
-	   'pattern=s'  => \$Pattern,
-	   'debug:i'    => \$Debug,
-	   'trim=s'     => \$Delimiter,
-	   'mountpt=s'  => \$LocalMount,
-	   'Port=i'     => \$HTTPPort,
-	   'nothreads'  => \$NoThreads,
-	   'unmount'    => \$UnMount,
-	   'XMLDummy=s' => \$XMLDummyDataPath,  # for debugging
-    ) or die $Usage;
+ pod2usage(1)                          if $Help;
+ pod2usage(-exitstatus=>0,-verbose=>2) if $Man;
 
 list_patterns_and_die() if $Pattern && $Pattern eq 'help';
 $NoThreads  ||= check_disable_threads();
@@ -354,8 +337,8 @@ if ($UnMount) {
     exec 'fusermount','-u',$mountpoint;
 }
 
-my $host       = shift or die $Usage;
-my $mountpoint = shift or die $Usage;
+my $host       = shift or pod2usage(1);
+my $mountpoint = shift or pod2usage(1);
 $mountpoint    = File::Spec->rel2abs($mountpoint);
 
 my $options  = join(',',@FuseOptions,'ro');
@@ -419,6 +402,8 @@ The following substitution patterns can be used in recording paths.
     %R   = Description
     %C   = Category
     %U   = RecGroup
+    %TC  = If part of a series, then Title, else Category
+    %ST  = If part of a series, then SubTitle, else Title
     %hn  = Hostname of the machine where the file resides
     %PI  = Program ID
     %SI  = Series ID
